@@ -8,18 +8,22 @@ FileHandler::FileHandler(QObject *parent) :
 
 void FileHandler::debugPfo() {
     for (int i=0; i<pfoModel.pfoName.length(); i++) {
+        #ifdef DBG
         qDebug() << i << "="
                  << pfoModel.pfoName[i].toString() << ":"
                  << pfoModel.pfoDesc[i].toString() << ":"
                  << pfoModel.pfoIsYahoo[i].toBool() ; //<< ":"
                  //<< pfoModel.pfoNum[i].toInt();
+        #endif
     }
 }
 
 // Overloaded function to eliminate appendPfo()
 Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
 {
+    #ifdef DBG
     qDebug() << "C_Info: storePfo() " << name << " " << desc << " " << isYahoo;
+    #endif
     pfoModel.pfoName.append(name);
     pfoModel.pfoDesc.append(desc);
     pfoModel.pfoIsYahoo.append(isYahoo);
@@ -28,7 +32,9 @@ Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
+        #ifdef DBG
         qDebug() << "Failed to open for write.";
+        #endif
 
         return -1;
     }
@@ -38,7 +44,9 @@ Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
     if (!pfoModel.pfoName.isEmpty()) {
         for (int i=0; i < pfoModel.pfoName.count(); i++) {
             ts << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool() << endl;
+            #ifdef DBG
             qDebug() << "C_Info: " << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool();
+            #endif
         }
     }
 
@@ -49,13 +57,17 @@ Q_INVOKABLE int FileHandler::storePfo(QString name, QString desc, bool isYahoo)
 
 Q_INVOKABLE int FileHandler::storePfoAll()
 {
+    #ifdef DBG
     qDebug() << "C_Info: storePfoAll()";
+    #endif
 
     QFile f( "/home/user/.stockona/portfolio.cfg" );
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
+        #ifdef DBG
         qDebug() << "Failed to open for write.";
+        #endif
 
         return -1;
     }
@@ -65,7 +77,9 @@ Q_INVOKABLE int FileHandler::storePfoAll()
     if (!pfoModel.pfoName.isEmpty()) {
         for (int i=0; i < pfoModel.pfoName.count(); i++) {
             ts << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool() << endl;
+            #ifdef DBG
             qDebug() << "C_Info: " << pfoModel.pfoName[i].toString() << ":" << pfoModel.pfoDesc[i].toString() << ":" << pfoModel.pfoIsYahoo[i].toBool();
+            #endif
         }
     }
 
@@ -81,7 +95,9 @@ Q_INVOKABLE int FileHandler::loadPfo()
         dir.mkpath("/home/user/.stockona/");
     }
 
+    #ifdef DBG
     qDebug() << "C_Info: loadPfo --->";
+    #endif
 
     QFile f( "/home/user/.stockona/portfolio.cfg" );
 
@@ -91,14 +107,18 @@ Q_INVOKABLE int FileHandler::loadPfo()
 
     if( !f.exists() )
     {
+        #ifdef DBG
         qDebug() << "C_Info: Local portfolio does not exist.";
+        #endif
 
         return -1;
     }
 
     if( !f.open( QIODevice::ReadOnly ) )
     {
+        #ifdef DBG
         qDebug() << "C_Info: Failed to open for read.";
+        #endif
 
         return -1;
     }
@@ -131,9 +151,11 @@ Q_INVOKABLE int FileHandler::loadPfo()
         else {
             // Fix format
             //f.remove();
+            #ifdef DBG
             qDebug() << "C_Info: Error in loading local portfolio.";
+            #endif
 
-            return -1;
+            return -2;
         }
     }
 
@@ -149,14 +171,18 @@ Q_INVOKABLE int FileHandler::loadPfo()
 }
 
 Q_INVOKABLE void FileHandler::setPfo(int idx, QString name, QString desc, bool isYahoo) {
+    #ifdef DBG
     qDebug() << "C_Info: Append: " << name << " " << desc << " " << isYahoo << "to" << idx;
+    #endif
     pfoModel.pfoName.replace(idx, name);
     pfoModel.pfoDesc.replace(idx, desc);
     pfoModel.pfoIsYahoo.replace(idx, isYahoo);
 }
 
 Q_INVOKABLE void FileHandler::removePfo(int idx) {
+    #ifdef DBG
     qDebug() << "C_Info: Remove portfolio entry " << idx;
+    #endif
     pfoModel.pfoName.removeAt(idx);
     pfoModel.pfoDesc.removeAt(idx);
     pfoModel.pfoIsYahoo.removeAt(idx);
@@ -176,13 +202,17 @@ Q_INVOKABLE int FileHandler::deletePfo()
 
     if( !f.exists() )
     {
+        #ifdef DBG
         qDebug() << "Local portfolio does not exist.";
+        #endif
 
         return -1;
     }
 
     f.remove();
+    #ifdef DBG
     qDebug() << "Delete local portfolio.";
+    #endif
 
     f.close();
 
@@ -199,20 +229,22 @@ int FileHandler::loadPosNum(int idx)
     filename.append(QString::number(idx));
     filename.append(".pos");
 
-    //qDebug() << "C_Info: loadPos ---> " << filename;
-
     QFile f( filename );
 
     if( !f.exists() )
     {
+        #ifdef DBG
         qDebug() << "C_Info: Position " << filename << " does not exist.";
+        #endif
         updatePfoNum(idx, 0);
         return -1;
     }
 
     if( !f.open( QIODevice::ReadOnly ) )
     {
+        #ifdef DBG
         qDebug() << "C_Info: Failed to open position " << filename << " for read.";
+        #endif
         updatePfoNum(idx, 0);
         return -1;
     }
@@ -241,7 +273,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
     filename.append(QString::number(idx));
     filename.append(".pos");
 
+    #ifdef DBG
     qDebug() << "C_Info: loadPos ---> " << filename;
+    #endif
 
     QFile f( filename );
 
@@ -253,7 +287,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
 
     if( !f.exists() )
     {
+        #ifdef DBG
         qDebug() << "C_Info: Position " << filename << " does not exist.";
+        #endif
         // Set pfo's num to 0
         updatePfoNum(idx, 0);
 
@@ -262,7 +298,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
 
     if( !f.open( QIODevice::ReadOnly ) )
     {
+        #ifdef DBG
         qDebug() << "C_Info: Failed to open position " << filename << " for read.";
+        #endif
         // Set pfo's num to 0
         updatePfoNum(idx, 0);
 
@@ -294,9 +332,11 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
         else {
             // Fix format
             //f.remove();
+            #ifdef DBG
             qDebug() << "C_Info: Error in loading local position.";
+            #endif
 
-            return -1;
+            return -2;
         }
     }
 
@@ -312,7 +352,9 @@ Q_INVOKABLE int FileHandler::loadPos(int idx)
 // Overloaded storePos
 Q_INVOKABLE int FileHandler::storePos(int idx, QString symbol, QString exchange, int share, int cost, int stop)
 {
+    #ifdef DBG
     qDebug() << "C_Info: storePos() " << symbol << " " << exchange << " " << share << " " << cost << " " << stop;
+    #endif
 
     posSymbol.append(symbol);
     posExg.append(exchange);
@@ -323,13 +365,17 @@ Q_INVOKABLE int FileHandler::storePos(int idx, QString symbol, QString exchange,
     QString filename = "/home/user/.stockona/";
     filename.append(QString::number(idx));
     filename.append(".pos");
+    #ifdef DBG
     qDebug() << "C_Info: storePos() into " << filename;
+    #endif
 
     QFile f( filename );
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
+        #ifdef DBG
         qDebug() << "Failed to open " << filename << " for write.";
+        #endif
 
         return -1;
     }
@@ -361,13 +407,17 @@ Q_INVOKABLE int FileHandler::storePosAll(int idx)
     QString filename = "/home/user/.stockona/";
     filename.append(QString::number(idx));
     filename.append(".pos");
+    #ifdef DBG
     qDebug() << "C_Info: storePosAll() into " << filename;
+    #endif
 
     QFile f( filename );
 
     if( !f.open( QIODevice::WriteOnly ) )
     {
+        #ifdef DBG
         qDebug() << "Failed to open " << filename << " for write.";
+        #endif
 
         return -1;
     }
@@ -398,7 +448,9 @@ Q_INVOKABLE int FileHandler::storePosAll(int idx)
 
 Q_INVOKABLE void FileHandler::setPos(int idx, QString symbol, QString exchange, int share, int cost, int stop)
 {
+    #ifdef DBG
     qDebug() << "C_Info: Append: " << symbol << " " << exchange << " " << share << " " << cost << " " << stop;
+    #endif
     posSymbol.replace(idx, symbol);
     posExg.replace(idx, share);
     posShare.replace(idx, exchange);
@@ -408,7 +460,9 @@ Q_INVOKABLE void FileHandler::setPos(int idx, QString symbol, QString exchange,
 
 Q_INVOKABLE void FileHandler::removePos(int idx)
 {
+    #ifdef DBG
     qDebug() << "C_Info: Remove pos entry " << idx;
+    #endif
     posSymbol.removeAt(idx);
     posExg.removeAt(idx);
     posShare.removeAt(idx);
@@ -426,11 +480,13 @@ Q_INVOKABLE void FileHandler::removePosFile(int idx)
 
 void FileHandler::debugPos() {
     for (int i=0; i<posSymbol.count(); i++) {
+        #ifdef DBG
         qDebug() << i << "="
                  << posSymbol[i].toString() << ":"
                  << posExg[i].toString() << ":"
                  << posShare[i].toInt() << ":"
                  << posCost[i].toInt() << ":"
                  << posStop[i].toInt();
+        #endif
     }
 }
