@@ -13,6 +13,8 @@
 #include <QIODevice>
 #include <QByteArray>
 
+//#define DBG
+
 class QNetworkAccessManager;
 class QNetworkReply;
 class QNetworkRequest;
@@ -36,10 +38,11 @@ signals:
 private:
     QNetworkAccessManager *nam;
     QNetworkReply *reply;
+    QString auth;
     bool downloading;
 
 private slots:
-     void slotReadyRead();
+    void parseAuth();
 
 signals:
     void statusChanged(const QString &status);
